************
Installation
************


Installing The Borg
===================

The easiest way to install theborg is with PyPi.  Note that you need to install "theborg".

.. code-block:: bash

    pip install theborg

To get the very latest version of the software, install it directly from GitHub.
    
.. code-block:: bash

    pip install git+https://github.com/dnidever/theborg


Dependencies
============

- numpy
- scipy
- astropy
- matplotlib
- dlnpyutils
- torch
